The claim_proofs library contains API for generating claim proofs and verifying them as part of the Asset Granularity Unique Identity project.

Re-exports

Modules

  • The claim_proofs library contains API for generating claim proofs and verifying them as part of the Asset Granularity Unique Identity project.

Structs

  • A Ristretto point, in compressed wire format.
  • A RistrettoPoint represents a point in the Ristretto group for Curve25519. Ristretto, a variant of Decaf, constructs a prime-order group as a quotient group of a subgroup of (the Edwards form of) Curve25519.
  • The Scalar struct holds an integer \(s < 2^{255} \) which represents an element of \(\mathbb Z / \ell\).

Traits

Functions