Crate confidential_identity_v2
source ·Expand description
The claim_proofs library contains API for generating
claim proofs and verifying them as part of the
Asset Granularity Unique Identity project.
Re-exports
pub use claim_proofs::CddClaimData;pub use claim_proofs::CddId;pub use claim_proofs::ScopeClaimData;pub use claim_proofs::ScopeClaimProof;pub use claim_proofs::ScopeClaimProofData;pub use confidential_identity_core;pub use curve25519_dalek;
Modules
- The
claim_proofslibrary contains API for generating claim proofs and verifying them as part of the Asset Granularity Unique Identity project.
Structs
- A Ristretto point, in compressed wire format.
- A
RistrettoPointrepresents a point in the Ristretto group for Curve25519. Ristretto, a variant of Decaf, constructs a prime-order group as a quotient group of a subgroup of (the Edwards form of) Curve25519. - The
Scalarstruct holds an integer \(s < 2^{255} \) which represents an element of \(\mathbb Z / \ell\).